OC.L10N.register(
    "deck",
    {
    "Finished" : "Završeno",
    "copy" : "kopiraj",
    "Done" : "Done",
    "The file was uploaded" : "Fajl je otpremljen",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Fajl za otpremljivanje premašuje upload_max_filesize direktivu u php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Fajl za otpremanje premašuje MAX_FILE_SIZE navedenu u HTML obrascu",
    "The file was only partially uploaded" : "Fajl je parcijalno otpremljen",
    "No file was uploaded" : "Nijedan fajl nije otpremljen",
    "Missing a temporary folder" : "Nedostaje privremena fascikla",
    "Could not write file to disk" : "Ne mogu da upišem fajl na disk",
    "A PHP extension stopped the file upload" : "PHP ekstenzija je zaustavila otpremanje fajla",
    "Add board" : "Dodaj tablu",
    "Move card" : "Premesti karticu",
    "Cancel" : "Otkaži",
    "Add card" : "Dodaj karticu",
    "Completed" : "Završeno",
    "Details" : "Detalji",
    "Sharing" : "Deljenje",
    "Tags" : "Oznake",
    "Activity" : "Aktivnost",
    "Undo" : "Opozovi",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Vlasnik",
    "Delete" : "Obriši",
    "Edit" : "Uredi",
    "Download" : "Preuzmi",
    "Attachments" : "Prilozi",
    "Save" : "Sačuvaj",
    "Reply" : "Odgovori",
    "Update" : "Ažuriraj",
    "Description" : "Opis",
    "Archive card" : "Arhiviraj karticu",
    "Delete card" : "Obriši karticu",
    "seconds ago" : "pre nekoliko sekundi",
    "Search" : "Traži",
    "Shared with you" : "Shared with you",
    "Edit board" : "Izmeni tablu",
    "Archive board" : "Arhiviraj tablu",
    "No notifications" : "Nema obaveštenja",
    "Delete board" : "Izbriši tablu",
    "Today" : "Danas",
    "Close" : "Zatvori",
    "Share" : "Podeli"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
